#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: path-pieces
version: 0.2.1
id: path-pieces-0.2.1-f62a4ee86afe2692f9fb79d2dd895499
key: pathp_4qW9xznk5mC6aJZVVgmWEO
license: BSD3
maintainer: Michael Snoyman <michael@snoyman.com>
stability: unstable
synopsis: Components of paths.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/path-pieces>.
category: Web, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Web.PathPieces
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/path-pieces-0.2.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/path-pieces-0.2.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/path-pieces-0.2.1
hs-libraries: HSpath-pieces-0.2.1-4qW9xznk5mC6aJZVVgmWEO
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
    time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
haddock-interfaces: /usr/share/doc/haskell-path-pieces/html/path-pieces.haddock
haddock-html: /usr/share/doc/haskell-path-pieces/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
